<template>
  <div class="card-list" v-change-height:card-list-box>
    <div class="card-list-box">
      <card-group :class="{ 'switch-card-group': !card.hide }" v-for="(card, cardIndex) in cardList" :key="cardIndex">
        <!-- 按钮组 -->
        <template v-slot:content>
          <div class="card-item" v-show="!card.hide">
            <div class="card-item-header">
              <!-- 左边 -->
              <div class="card-item-header-left">
                <!-- 功能标识 -->
                <div class="card-item-header-left-main">
                  <!-- 图标 -->
                  <div class="card-item-header-left-main-icon iconfont" :class="`iconfont-${card.icon.key}`" />
                  <div class="card-item-header-left-main-text">
                    <!-- 功能名字 -->
                    <p class="card-item-header-left-main-text-name" v-text="card.name" />
                    <!-- 底部文字 -->
                    <p class="card-item-header-left-main-text-footer" v-text="card.footer" />
                  </div>
                  <gree-dropdown
                    v-model="dropdownInfo.isDropdownShow"
                    theme="dark"
                    class-name="custom-dropdown--block"
                    :placement="dropdownInfo.placement"
                    trigger="click"
                    v-if="card.key === 'NoBodySvSt'"
                  >
                    <div class="custom-content">
                      {{ dropdownInfo.tips }}
                      <gree-icon name="fail" @click="dropdownInfo.isDropdownShow = false" />
                    </div>
                    <template #reference>
                      <gree-icon name="question-o" size="sm" />
                    </template>
                  </gree-dropdown>
                </div>
                <!-- 描述文字 -->
                <p
                  class="card-item-header-left-describe"
                  @click="showPopup(card.key)"
                  :class="{ on: card.icon.type === 'on' }"
                  v-text="card.describe"
                  v-if="setDescribe(card.key)"
                />
              </div>
              <gree-divider class="card-item-header-left-divider" direction="vertical" v-if="setDescribe(card.key)" />
              <!-- 右边 -->
              <div class="card-item-header-right">
                <!-- 按钮 -->
                <gree-switch
                  class="card-item-header-right-switch"
                  :size="switchSize"
                  :class="{ on: card.icon.type === 'on' }"
                  :value="card.icon.type === 'on'"
                  @click="card.handler(card.key)"
                />
              </div>
            </div>
            <DazzlingCard v-if="card.key === 'Dazzling'" />
          </div>
        </template>
      </card-group>
    </div>
    <popup-group />
  </div>
</template>

<script>
import { Switch, Dropdown, RadioBox, RadioGroup, Block, Icon, Grid, GridItem, Divider } from 'gree-ui';
import { glyphs } from '@assets/iconfont/iconfont.json';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';
import { mapMutations, mapState, mapGetters } from 'vuex';
import PopupGroup from '@/components/Popup/index';
import temUnChange from '@/mixins/tem';
import DazzlingCard from './DazzlingCard';

export default {
  name: 'card-list',
  components: {
    [Icon.name]: Icon,
    [Grid.name]: Grid,
    [Block.name]: Block,
    [Switch.name]: Switch,
    [Divider.name]: Divider,
    [Dropdown.name]: Dropdown,
    [BtnGroup.name]: BtnGroup,
    [RadioBox.name]: RadioBox,
    [GridItem.name]: GridItem,
    [CardGroup.name]: CardGroup,
    [RadioGroup.name]: RadioGroup,
    [PopupGroup.name]: PopupGroup,
    DazzlingCard
  },
  data() {
    return {
      isShowdescribe: true,
      dropdownInfo: {
        name: '',
        icon: 'question-o',
        isDropdownShow: false,
        placement: 'top',
        tips: '设定时间内检测无人，空调进入停机 状态，有人后恢复工作'
      },
      jsonMap: {
        1: 'CoolSvStTemMin',
        2: 'HumiSvStTemMin',
        4: 'HeatSvStTemMax',
        6: 'Heat3DSvStTemMax',
        7: 'Heat2SvStTemMax'
      },
      SmartWindMap: {
        0: '',
        1: '智能',
        2: '风随人',
        3: '风避人',
        4: '环绕风'
      },
      NoBodySvStMap: {
        0: '8小时',
        1: '4小时',
        2: '2小时',
        3: '1小时'
      }
    };
  },
  mixins: [temUnChange],
  computed: {
    ...mapState('control', {
      Pow: state => state.dataObject.Pow,
      Air: state => state.dataObject.Air,
      Mod: state => state.dataObject.Mod,
      TemUn: state => state.dataObject.TemUn,
      SmartWind: state => state.dataObject.SmartWind,
      HumiEnable: state => state.dataObject.HumiEnable,
      UnmanedShutDown: state => state.dataObject.UnmanedShutDown,
      UnmanedOffTime: state => state.dataObject.UnmanedOffTime,
      CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      CoolSvStTemMinD: state => state.dataObject.CoolSvStTemMinD || 18,
      HumiSvStTemMinD: state => state.dataObject.HumiSvStTemMinD || 18,
      HeatSvStTemMaxD: state => state.dataObject.HeatSvStTemMaxD || 18,
      Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18,
      Heat2SvStTemMaxD: state => state.dataObject.Heat2SvStTemMaxD || 18,
      Heat3DSvStTemMaxD: state => state.dataObject.Heat3DSvStTemMaxD || 18
    }),
    ...mapGetters([
      'cardFuncDefine',
      'modTextKey',
      'modCurrentStatusName',
      'spModCurrentStatusName',
      'fanDefine',
      'fanCurrentStatusName',
      'cardFuncCurrentStatusName'
    ]),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    cardList() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.cardFuncDefine.map(model => {
        const identifier = model.identifier;
        if (!this.statusMap[identifier])
          return {
            icon: {},
            handler: () => {
              console.log('Undefined function');
            }
          };
        // 当前status定义
        const status = this.statusMap[identifier].status;
        // 取名称
        const defaultNameKey = `btn.${identifier}`;
        const footerKey = `footer.${identifier}`;
        const describeKey = `describe.${identifier}`;

        const statusNameText = status.name;
        const stateNameText = `${defaultNameKey}_${statusNameText}`;

        const name = stateNameText === this.$language(stateNameText) ? this.$language(defaultNameKey) : this.$language(stateNameText);
        const footer = this.parseStr(footerKey);
        const describe = this.parseStr(describeKey);
        // 图标
        const icon = glyphs.some(item => item.font_class === status.icon.key) ? status.icon : { key: 'undefined', type: 'off' };
        // 是否隐藏
        const hide = this.blindModelArr.includes(identifier);
        // 执行的方法
        const handler = (identifier, disable = false) => {
          disable || this.$stateMachine.nextStatus(identifier);
        };
        return { key: identifier, name, icon, hide, handler, footer, describe };
      });
      return result;
    },
    svstTextList() {
      if (this.modCurrentStatusName === 'status_1' || this.modCurrentStatusName === 'status_6' || this.modCurrentStatusName === 'status_7')
        return this.$language('svst.upperlimit');
      return this.$language('svst.lowerlimit');
    },
    modText() {
      return this.$language(this.modTextKey);
    },
    describeUnit() {
      return !this.TemUn ? '℃' : '℉';
    },
    switchSize() {
      return Math.floor((window['lib'].flexible.rem / 108) * 88);
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    setDescribe(val) {
      if (val === 'Air') {
        if (this.Pow || !this.Air) {
          return false;
        } else {
          return true;
        }
      } else if (val === 'Dazzling') {
        return false;
      } else {
        return true;
      }
    },
    parseStr(str) {
      //  没想好怎么处理，记得改
      if (str === 'describe.SvSt') {
        const { modText } = this;
        const jsonMap = {
          1: 'CoolSvStTemMinD',
          2: 'HumiSvStTemMinD',
          4: 'HeatSvStTemMaxD',
          6: 'Heat3DSvStTemMaxD',
          7: 'Heat2SvStTemMaxD'
        };
        if (!this.TemUn) {
          return this.$language(modText) + this.svstTextList + this[this.jsonMap[this.Mod]] + this.describeUnit;
        } else {
          return this.$language(modText) + this.svstTextList + this[jsonMap[this.Mod]] + this.describeUnit;
        }
      } else if (str === 'describe.Air') {
        const status = this.fanDefine.statusDefine[this.fanCurrentStatusName];
        const fanStatusName = status.name + '档';
        return fanStatusName;
      } else if (str === 'describe.SmartWind') {
        const statusName = this.SmartWindMap[this.SmartWind];
        return statusName;
      } else if (str === 'describe.NoBodySvSt') {
        if (!this.UnmanedShutDown) {
          return '';
        }
        const statusName = this.NoBodySvStMap[this.UnmanedOffTime];
        return statusName;
      }
      return this.$language(str);
    },
    onClickCard(v) {
      console.log(123, v);
      // this.send
    },
    showPopup(key) {
      this.SetPopup({ [key + 'Popup']: true });
      console.log('cardKey', [key + 'Popup']);
    }
  }
};
</script>

<style lang="scss">
.gree-dropdown.custom-dropdown--block {
  width: 700px;
  .gree-dropdown__arrow {
    color: rgba(0, 0, 0, 0.8);
  }
  .gree-dropdown__content {
    background-color: rgba(0, 0, 0, 0.8) !important;
  }
  .custom-content {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;
    padding: 30px 38px;
    color: #ffffff;
    font-size: 36px;
    text-align: left;
    max-width: 720px;
    .gree-icon.icon-font {
      color: rgba(255, 255, 255, 0.8);
      font-size: 46px;
    }
  }
}
.card-list {
  position: relative;
  .switch-card-group {
    padding-bottom: 40px;
  }
  .card-item {
    width: 100%;
    .card-item-header {
      height: 160px;
      width: 100%;
      display: flex;
      align-items: center;
      justify-content: space-between;
      &-left {
        height: 100%;
        width: 100%;
        display: flex;
        align-items: center;
        justify-content: space-between;
        &-main {
          height: 100%;
          width: 100%;
          margin-left: 20px;
          display: flex;
          justify-content: flex-start;
          align-items: center;
          &-icon {
            $iconHeight: 68px;
            background-image: linear-gradient(0deg, rgb(106, 194, 166), rgb(141, 214, 191));
            height: $iconHeight;
            width: $iconHeight;
            line-height: $iconHeight;
            margin-left: 42px;
            border-radius: 50%;
            font-size: 40px;
            color: #fff;
            text-align: center;
          }
          .iconfont-zhinengsongfeng {
            background-image: linear-gradient(0deg, #7fb5f7, #6da4e7);
          }
          .iconfont-Dazzling {
            background-image: linear-gradient(0deg, #fcb28d, #ffac83);
          }

          &-text {
            padding-left: 20px;
            padding-right: 20px;
            &-name {
              font-size: 48px;
              color: #404657;
            }
            &-footer {
              font-size: 36px;
              color: #989898;
            }
          }
        }
        &-describe {
          text-align: right;
          width: 420px;
          font-size: 46px;
          margin-right: 24px;
          white-space: nowrap;
          color: #989898;
          &.on {
            color: #71acf1;
          }
        }
        &-divider {
          height: 79px;
          margin: 0;
        }
      }
      &-right {
        padding: 0 52px 0 24px;
        width: auto;
        height: 100%;
        display: flex;
        justify-content: flex-start;
        align-items: center;
        &-switch {
          background-color: #c5c5c5;
          &.on {
            background-color: #71acf1;
          }
        }
      }
    }
  }
}
</style>
